==> eiffelstudio-16.05.tar: F_code/C8/mu376.c <==
/*
 * Code for class MUTEX
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "mu376.h"
#include <eif_threads.h>
#include "eif_threads.h"

#ifdef __cplusplus
extern "C" {
#endif

#ifndef INLINE_F85_2046
static EIF_POINTER inline_F85_2046 (void)
{
	return eif_thr_thread_id();
	;
}
#define INLINE_F85_2046
#endif

#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {MUTEX}.make */
void F878_6334 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER tp1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("make", 877, Current, 0, 0, 10433);
	RTGC;
	RTHOOK(1);
	tp1 = (EIF_POINTER) eif_thr_mutex_create();
	*(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_1_) = (EIF_POINTER) tp1;
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {MUTEX}.is_set */
EIF_BOOLEAN F878_6336 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER tp1;
	EIF_POINTER tp2;
	EIF_POINTER tp3;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("is_set", 877, Current, 0, 0, 10435);
	RTGC;
	RTHOOK(1);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_1_);
	{
		/* INLINED CODE (default_pointer) */
		tp2 = (EIF_POINTER)  0;
		/* END INLINED CODE */
	}
	tp3 = tp2;
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(tp1 != tp3);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {MUTEX}.lock */
void F878_6337 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER tp1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("lock", 877, Current, 0, 0, 10436);
	RTGC;
	RTHOOK(1);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_1_);
	eif_thr_mutex_lock(tp1);
	RTHOOK(2);
	tp1 = inline_F85_2046();
	*(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_0_) = (EIF_POINTER) tp1;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {MUTEX}.try_lock */
EIF_BOOLEAN F878_6338 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER tp1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("try_lock", 877, Current, 0, 0, 10437);
	RTGC;
	RTHOOK(1);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_1_);
	Result = (EIF_BOOLEAN) EIF_TEST(eif_thr_mutex_trylock(tp1));
	RTHOOK(2);
	if (Result) {
		RTHOOK(3);
		tp1 = inline_F85_2046();
		*(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_0_) = (EIF_POINTER) tp1;
	}
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
}

/* {MUTEX}.unlock */
void F878_6339 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER tp1;
	EIF_POINTER tp2;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("unlock", 877, Current, 0, 0, 10438);
	RTGC;
	RTHOOK(1);
	{
		/* INLINED CODE (default_pointer) */
		tp1 = (EIF_POINTER)  0;
		/* END INLINED CODE */
	}
	tp2 = tp1;
	*(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_0_) = (EIF_POINTER) tp2;
	RTHOOK(2);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_1_);
	eif_thr_mutex_unlock(tp1);
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {MUTEX}.destroy */
void F878_6340 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER tp1;
	EIF_POINTER tp2;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("destroy", 877, Current, 0, 0, 10439);
	RTGC;
	RTHOOK(1);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_1_);
	eif_thr_mutex_destroy(tp1);
	RTHOOK(2);
	{
		/* INLINED CODE (default_pointer) */
		tp1 = (EIF_POINTER)  0;
		/* END INLINED CODE */
	}
	tp2 = tp1;
	*(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_1_) = (EIF_POINTER) tp2;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {MUTEX}.dispose */
void F878_6343 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER loc1 = (EIF_POINTER) 0;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("dispose", 877, Current, 1, 0, 10442);
	RTGC;
	RTHOOK(1);
	if (F878_6336(Current)) {
		RTHOOK(2);
		tb1 = '\01';
		if (!(EIF_BOOLEAN)(*(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_0_) == loc1)) {
			tb1 = (EIF_BOOLEAN)(*(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_0_) == inline_F85_2046());
		}
		if (tb1) {
			RTHOOK(3);
			F878_6340(Current);
		}
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {MUTEX}.eif_thr_mutex_create */
EIF_POINTER F878_6345 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("eif_thr_mutex_create", 877, Current, 0, 0, 10444);Result = (EIF_POINTER) eif_thr_mutex_create();
	
	RTHOOK(1);
	RTLE;
	RTEE;
	return Result;
}

/* {MUTEX}.eif_thr_mutex_lock */
void F878_6346 (EIF_REFERENCE Current, EIF_POINTER arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("eif_thr_mutex_lock", 877, Current, 0, 1, 10445);
	EIF_ENTER_C;eif_thr_mutex_lock(arg1);
	
	EIF_EXIT_C;
	RTGC;
	RTHOOK(1);
	RTLE;
	RTEE;
}

/* {MUTEX}.eif_thr_mutex_unlock */
void F878_6347 (EIF_REFERENCE Current, EIF_POINTER arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("eif_thr_mutex_unlock", 877, Current, 0, 1, 10446);eif_thr_mutex_unlock(arg1);
	
	RTHOOK(1);
	RTLE;
	RTEE;
}

/* {MUTEX}.eif_thr_mutex_trylock */
EIF_BOOLEAN F878_6348 (EIF_REFERENCE Current, EIF_POINTER arg1)
{
	GTCX
	RTEX;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("eif_thr_mutex_trylock", 877, Current, 0, 1, 10447);
	EIF_ENTER_C;Result = (EIF_BOOLEAN) EIF_TEST(eif_thr_mutex_trylock(arg1));
	
	EIF_EXIT_C;
	RTGC;
	RTHOOK(1);
	RTLE;
	RTEE;
	return Result;
}

/* {MUTEX}.eif_thr_mutex_destroy */
void F878_6349 (EIF_REFERENCE Current, EIF_POINTER arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("eif_thr_mutex_destroy", 877, Current, 0, 1, 10448);eif_thr_mutex_destroy(arg1);
	
	RTHOOK(1);
	RTLE;
	RTEE;
}

void EIF_Minit376 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C8/mu376.c <==
/*
 * Code for class MUTEX
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "mu376.h"
#include "eif_built_in.h"
#include <eif_threads.h>
#include "eif_threads.h"

#ifdef __cplusplus
extern "C" {
#endif

#ifndef INLINE_F225_2845
static EIF_POINTER inline_F225_2845 (void)
{
	return eif_thr_thread_id();
	;
}
#define INLINE_F225_2845
#endif

#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {MUTEX}.make */
void F658_5135 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER tp1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("make", 657, Current, 0, 0, 5812);
	RTGC;
	RTHOOK(1);
	tp1 = (EIF_POINTER) eif_thr_mutex_create();
	*(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_1_) = (EIF_POINTER) tp1;
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {MUTEX}.is_set */
EIF_BOOLEAN F658_5137 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER tp1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("is_set", 657, Current, 0, 0, 5814);
	RTGC;
	RTHOOK(1);
	Result = '\01';
	{
		/* INLINED CODE (default_pointer) */
		tp1 = (EIF_POINTER)  0;
		/* END INLINED CODE */
	}
	if (!(EIF_BOOLEAN)(*(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_1_) != tp1)) {
		Result = (EIF_BOOLEAN) !(EIF_BOOLEAN) eif_builtin_PLATFORM_is_thread_capable;
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {MUTEX}.lock */
void F658_5138 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER tp1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("lock", 657, Current, 0, 0, 5815);
	RTGC;
	RTHOOK(1);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_1_);
	F658_5147(Current, tp1);
	RTHOOK(2);
	tp1 = inline_F225_2845();
	*(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_0_) = (EIF_POINTER) tp1;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {MUTEX}.unlock */
void F658_5140 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER tp1;
	EIF_POINTER tp2;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("unlock", 657, Current, 0, 0, 5817);
	RTGC;
	RTHOOK(1);
	{
		/* INLINED CODE (default_pointer) */
		tp1 = (EIF_POINTER)  0;
		/* END INLINED CODE */
	}
	tp2 = tp1;
	*(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_0_) = (EIF_POINTER) tp2;
	RTHOOK(2);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_1_);
	eif_thr_mutex_unlock(tp1);
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {MUTEX}.destroy */
void F658_5141 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER tp1;
	EIF_POINTER tp2;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("destroy", 657, Current, 0, 0, 5818);
	RTGC;
	RTHOOK(1);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_1_);
	eif_thr_mutex_destroy(tp1);
	RTHOOK(2);
	{
		/* INLINED CODE (default_pointer) */
		tp1 = (EIF_POINTER)  0;
		/* END INLINED CODE */
	}
	tp2 = tp1;
	*(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_1_) = (EIF_POINTER) tp2;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {MUTEX}.dispose */
void F658_5144 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER tp1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("dispose", 657, Current, 0, 0, 5821);
	RTGC;
	RTHOOK(1);
	tb1 = '\0';
	if (F658_5137(Current)) {
		tb2 = '\01';
		{
			/* INLINED CODE (default_pointer) */
			tp1 = (EIF_POINTER)  0;
			/* END INLINED CODE */
		}
		if (!(EIF_BOOLEAN)(*(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_0_) == tp1)) {
			tb2 = (EIF_BOOLEAN)(*(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_0_) == inline_F225_2845());
		}
		tb1 = tb2;
	}
	if (tb1) {
		RTHOOK(2);
		F658_5141(Current);
	}
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {MUTEX}.eif_thr_mutex_create */
EIF_POINTER F658_5146 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_POINTER Result = ((EIF_POINTER) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("eif_thr_mutex_create", 657, Current, 0, 0, 5807);Result = (EIF_POINTER) eif_thr_mutex_create();
	
	RTHOOK(1);
	RTLE;
	RTEE;
	return Result;
}

/* {MUTEX}.eif_thr_mutex_lock */
void F658_5147 (EIF_REFERENCE Current, EIF_POINTER arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("eif_thr_mutex_lock", 657, Current, 0, 1, 5808);
	EIF_ENTER_C;eif_thr_mutex_lock(arg1);
	
	EIF_EXIT_C;
	RTGC;
	RTHOOK(1);
	RTLE;
	RTEE;
}

/* {MUTEX}.eif_thr_mutex_unlock */
void F658_5148 (EIF_REFERENCE Current, EIF_POINTER arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("eif_thr_mutex_unlock", 657, Current, 0, 1, 5809);eif_thr_mutex_unlock(arg1);
	
	RTHOOK(1);
	RTLE;
	RTEE;
}

/* {MUTEX}.eif_thr_mutex_destroy */
void F658_5150 (EIF_REFERENCE Current, EIF_POINTER arg1)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("eif_thr_mutex_destroy", 657, Current, 0, 1, 5811);eif_thr_mutex_destroy(arg1);
	
	RTHOOK(1);
	RTLE;
	RTEE;
}

void EIF_Minit376 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
